#[non_exhaustive]pub enum WgpuRenderStateAccessError {
Inactive,
AlreadyBorrowed,
}Expand description
Error returned while borrowing the transient WGPU draw-callback state.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Inactive
No WGPU render state is active on the current Dear ImGui Context.
AlreadyBorrowed
The active callback state is already borrowed by an outer scoped access.