Uniforms

Struct Uniforms 

#[repr(C)]
pub struct Uniforms { pub mvp: [[f32; 4]; 4], pub gamma: f32, pub _padding: [f32; 3], }
Uniform data structure

This corresponds to the Uniforms struct in the C++ implementation. Contains the MVP matrix and gamma correction value.

Fields

mvp: [[f32; 4]; 4]

Model-View-Projection matrix (4x4 f32 matrix)

gamma: f32

Gamma correction value

_padding: [f32; 3]

Padding to ensure proper alignment

Implementations

Source

impl Uniforms

pub fn new() -> Self

Create new uniforms with identity matrix and default gamma

pub fn create_orthographic_matrix( display_pos: [f32; 2], display_size: [f32; 2], ) -> [[f32; 4]; 4]

Create orthographic projection matrix for Dear ImGui

This matches the matrix calculation in ImGui_ImplWGPU_SetupRenderState

pub fn gamma_for_format(format: TextureFormat) -> f32

Determine gamma value based on texture format

This matches the gamma detection logic in ImGui_ImplWGPU_SetupRenderState from the official C++ implementation, supporting all sRGB texture formats.

pub fn set_mvp(&mut self, mvp: [[f32; 4]; 4])

Update the MVP matrix

pub fn set_gamma(&mut self, gamma: f32)

Update the gamma value

pub fn update(&mut self, mvp: [[f32; 4]; 4], gamma: f32)

Update both MVP and gamma