pub struct FramebufferExtent { /* private fields */ }Expand description
Physical dimensions of the WGPU render target receiving Dear ImGui commands.
WGPU render passes do not expose attachment dimensions. Applications must therefore pass the extent of the texture view used to create the render pass instead of asking the renderer to infer it from Dear ImGui’s logical display metrics.
Implementations
Sourceimpl FramebufferExtent
impl FramebufferExtent